Package: shinyvalidate
Title: Input Validation for Shiny Apps
Version: 0.1.3
Authors@R: c(
    person("Carson", "Sievert", , "carson@posit.co", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-4958-2844")),
    person("Richard", "Iannone", , "rich@posit.co", c("aut"),
           comment = c(ORCID = "0000-0003-3925-190X")),
    person("Joe", "Cheng", , "joe@posit.co", c("aut")),
    person("Posit Software, PBC", role = c("cph", "fnd"))
    )
Description: Improves the user experience of Shiny apps by helping to
    provide feedback when required inputs are missing, or input values
    are not valid.
License: MIT + file LICENSE
URL: https://rstudio.github.io/shinyvalidate/,
        https://github.com/rstudio/shinyvalidate
BugReports: https://github.com/rstudio/shinyvalidate/issues
Encoding: UTF-8
Imports: shiny (>= 1.6), htmltools (>= 0.5.1.1), rlang (>= 0.4.10),
        glue (>= 1.4.2)
RoxygenNote: 7.2.3
Suggests: testthat, knitr, rmarkdown, covr
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2023-10-03 21:59:53 UTC; cpsievert
Author: Carson Sievert [aut, cre] (<https://orcid.org/0000-0002-4958-2844>),
  Richard Iannone [aut] (<https://orcid.org/0000-0003-3925-190X>),
  Joe Cheng [aut],
  Posit Software, PBC [cph, fnd]
Maintainer: Carson Sievert <carson@posit.co>
Repository: CRAN
Date/Publication: 2023-10-04 15:00:02 UTC
Built: R 4.6.0; ; 2026-04-26 13:27:34 UTC; unix
